<?php defined( 'ABSPATH' ) or die( "Cannot access pages directly." );

// Domain only functions start from here...
function wcop_check_domain() {
	$response                  = whcom_check_domain_function( $_POST );
	$response['response_form'] = '';
	$domain_ext                = ( ! empty( $_POST['ext'] ) ) ? esc_attr( $_POST['ext'] ) : '';
	$domain_name               = ( ! empty( $_POST['domain'] ) ) ? esc_attr( $_POST['domain'] ) : '';
	$domain_type               = ( ! empty( $_POST['domaintype'] ) ) ? esc_attr( $_POST['domaintype'] ) : '';
	$domain_duration           = '';
	$tld_details               = whcom_get_tld_details( $domain_ext );
	$tld_price                 = '';
	if ( ! empty( $tld_details[ $domain_type . '_price' ] ) ) {
		foreach ( $tld_details[ $domain_type . '_price' ] as $dur => $price ) {
			if ( $price >= 0 ) {
				$tld_price       = (string) $dur . ' ';
				$tld_price       .= ( $dur == 1 ) ? esc_html__( ' Year', "whcom" ) : esc_html__( ' Years', "whcom" );
				$tld_price       .= esc_html__( ' for ', "whcom" );
				$tld_price       .= whcom_format_amount( [ 'amount' => $price, 'add_suffix' => 'yes' ] );
				$domain_duration = $dur;
				break;
			}
		}
	}
	switch ( $domain_type ) {
		case 'register' :
			{
				if ( $response['status'] == 'OK' ) {
					ob_start() ?>
                    <div class="whcom_text_center whcom_text_success whcom_text_2x">
						<?php esc_html_e( 'Congratulations', "whcom" ) ?>!
                        <strong><?php echo $domain_name ?><?php echo $domain_ext ?></strong> <?php esc_html_e( 'is available', "whcom" ) ?>
                        !
                    </div>
                    <div class="whcom_text_center whcom_margin_bottom_15">
						<?php esc_html_e( 'Continue to register this domain for', "whcom" ) ?>
						<?php echo $tld_price; ?>
                    </div>
					<?php $response['message'] = ob_get_clean();
				}
				else {
					ob_start() ?>
                    <div class="whcom_text_center whcom_margin_bottom_15 whcom_text_danger whcom_text_2x">
                        <strong><?php echo $domain_name ?><?php echo $domain_ext ?></strong> <?php esc_html_e( 'is unavailable', "whcom" ) ?>
                    </div>
					<?php $response['message'] = ob_get_clean();
				}
				break;
			}
		case 'transfer' :
			{
				if ( $response['status'] == 'OK' ) {
					ob_start() ?>
                    <div class="whcom_text_success whcom_margin_bottom_30 whcom_text_center">
                        <div class="whcom_margin_bottom_15 whcom_text_2x">
							<?php esc_html_e( 'Your domain is eligible for transfer', "whcom" ) ?>!
                        </div>
						<?php esc_html_e( 'Please ensure you have unlocked your domain at your current registrar before continuing.', "whcom" ) ?>
                    </div>
                    <div class="whcom_text_center whcom_margin_bottom_15">
						<?php esc_html_e( 'Transfer to us and extend by', "whcom" ) ?>
						<?php echo $tld_price; ?>
                    </div>
					<?php $response['message'] = ob_get_clean();
				}
				else {
					ob_start() ?>
                    <div class="whcom_alert whcom_text_center">
                        <div class="whcom_margin_bottom_15 whcom_text_danger whcom_text_2x">
							<?php esc_html_e( 'Not Eligible for Transfer', "whcom" ) ?>
                        </div>
                        <div class="whcom_margin_bottom_15">
							<?php esc_html_e( 'The domain you entered does not appear to be registered.', "whcom" ) ?>
                        </div>
                        <div class="whcom_margin_bottom_15">
							<?php esc_html_e( 'If the domain was registered recently, you may need to try again later.', "whcom" ) ?>
                        </div>
                        <div class="whcom_margin_bottom_15">
							<?php esc_html_e( 'Alternatively, you can perform a search to register this domain.', "whcom" ) ?>
                        </div>
                    </div>
					<?php $response['message'] = ob_get_clean();
				}
				break;
			}
	}


	if ( $response['status'] == 'OK' ) {
		ob_start(); ?>

        <form class="wcop_domain_action_select" method="post">
            <input type="hidden" name="domain" value="<?php echo $response['domain'] ?>">
            <input type="hidden" name="ext" value="<?php echo $response['ext'] ?>">
            <input type="hidden" name="domaintype" value="<?php echo $response['domaintype'] ?>">
            <input type="hidden" name="regperiod" value="<?php echo $response['regperiod'] ?>">
            <input type="hidden" name="action" value="wcop_domain_action_select">

            <div class="whcom_form_field whcom_text_center">
                <div class="whcom_checkbox_container">
                    <label for="wcop_domain_configure" class="whcom_radio whcom_checked">
                        <input type="radio" name="domain_action" id="wcop_domain_configure" value="configure_domain"
                               checked>
						<?php esc_html_e( 'Configure Domain', "whcom" ) ?>
                    </label> <label for="wcop_domain_product_attach" class="whcom_radio">
                        <input type="radio" name="domain_action" id="wcop_domain_product_attach" value="attach_product">
						<?php esc_html_e( 'Attach Product', "whcom" ) ?>
                    </label>
                </div>
            </div>
            <div class="whcom_form_field whcom_form_field_horizontal whcom_text_center_xs">
                <button type="submit"><?php esc_html_e( 'Continue', "whcom" ) ?></button>
            </div>
        </form>

		<?php
		$response['response_form'] = ob_get_clean();
	}

	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_check_domain', 'wcop_check_domain' );
add_action( 'wp_ajax_nopriv_wcop_check_domain', 'wcop_check_domain' );

function wcop_domain_action_select() {
	$response = [
		'status'        => 'ERROR',
		'message'       => esc_html__( 'Something went wrong...', "whcom" ),
		'response_form' => '',
	];
	if ( ! empty( $_POST ) && ( ! empty( $_POST['domain_action'] ) ) && ( ! empty( $_POST['domain'] ) ) ) {
		if ( $_POST['domain_action'] == 'configure_domain' ) {
			$response['response_form'] = wcop_render_domain_config_form( esc_attr( $_POST['domain'] ), esc_attr( $_POST['domaintype'] ) )['response_form'];
			if ( $response['response_form'] ) {

				$response['status']  = 'OK';
				$response['message'] = esc_html__( 'Kindly fill below form to proceed with domain order', "whcom" );
			}
		}
		if ( $_POST['domain_action'] == 'attach_product' ) {
			$tld_details = whcom_get_tld_details( $_POST['ext'] );
			if ( ! empty( $tld_details ) && ! empty( $tld_details['min_price'][ $_POST['domaintype'] ] ) ) {

				whcom_add_update_cart_item( [
					'domain'     => $_POST['domain'],
					'domaintype' => $_POST['domaintype'],
					'regperiod'  => $tld_details['min_price'][ $_POST['domaintype'] ]['duration']
				] );
				$response['response_form'] = do_shortcode( '[whmpress_cart_list_products domain_products="yes"]' );
				if ( $response['response_form'] ) {
					$response['status']  = 'OK';
					$response['message'] = '<div class="whcom_alert whcom_alert_success">' . esc_html__( 'Domain is added to cart. Kindly select an item from below list', "whcom" ) . '</div>';
				}
			}
		}
	}
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_domain_action_select', 'wcop_domain_action_select' );
add_action( 'wp_ajax_nopriv_wcop_domain_action_select', 'wcop_domain_action_select' );


function wcop_add_domain_to_cart() {
	$response = [
		'status'  => 'ERROR',
		'message' => esc_html__( 'Something went wrong, kindly try again later ...', "whcom" )
	];
	$response = whcom_add_update_cart_item( $_POST );
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_add_domain_to_cart', 'wcop_add_domain_to_cart' );
add_action( 'wp_ajax_nopriv_wcop_add_domain_to_cart', 'wcop_add_domain_to_cart' );


// Product functions start from here...
// Check product domain where applicable
function wcop_check_product_domain() {

	$response                           = whcom_check_domain_function( $_POST );
	$cart_index                         = ( isset( $_POST['cart_index'] ) && $_POST['cart_index'] > - 1 ) ? (int) $_POST['cart_index'] : '-1';
	$response['domain_attachment_form'] = '';
	$domain_ext                         = ( ! empty( $_POST['ext'] ) ) ? esc_attr( $_POST['ext'] ) : '';
	$domain_name                        = ( ! empty( $_POST['domain'] ) ) ? esc_attr( $_POST['domain'] ) : '';
	$domain_type                        = ( ! empty( $_POST['domaintype'] ) ) ? esc_attr( $_POST['domaintype'] ) : '';
	$tld_details                        = whcom_get_tld_details( $domain_ext );
	$tld_price                          = '';
	$domain_duration                    = '';

	if ( ! empty( $tld_details[ $domain_type . '_price' ] ) ) {
		foreach ( $tld_details[ $domain_type . '_price' ] as $dur => $price ) {
			if ( $price >= 0 ) {
				$tld_price       = (string) $dur . ' ';
				$tld_price       .= ( $dur == 1 ) ? esc_html__( 'Year', "whcom" ) : esc_html__( 'Years', "whcom" );
				$tld_price       .= ' ' . esc_html__( 'for', "whcom" ) . ' ';
				$tld_price       .= whcom_format_amount( [ 'amount' => $price, 'add_suffix' => 'yes' ] );
				$domain_duration = $dur;
				break;
			}
		}
	}
	$response['domaintype'] = $domain_type;
	switch ( $domain_type ) {
		case 'register' :
			{
				if ( $response['status'] == 'OK' ) {
					ob_start() ?>
                    <div class="whcom_text_center whcom_text_success whcom_text_2x">
						<?php esc_html_e( 'Congratulations!', "whcom" ) ?>
                        <strong><?php echo $domain_name ?><?php echo $domain_ext ?></strong> <?php esc_html_e( 'is available!', "whcom" ) ?>
                    </div>
                    <div class="whcom_text_center whcom_margin_bottom_15">
						<?php esc_html_e( 'Continue to register this domain for ', "whcom" ) ?>
						<?php echo $tld_price; ?>
                    </div>
                    <form class="wcop_attach_product_domain whcom_text_center_xs" method="post">
                        <input type="hidden" name="action" value="wcop_attach_product_domain">
                        <input type="hidden" name="cart_index" value="<?php echo $cart_index; ?>">
                        <input type="hidden" name="domain" value="<?php echo $domain_name . $domain_ext; ?>">
                        <input type="hidden" name="type" value="<?php echo $domain_type; ?>">
                        <input type="hidden" name="regperiod" value="<?php echo $domain_duration; ?>">
                        <button type="submit"><?php esc_html_e( 'Continue', "whcom" ) ?></button>
                    </form>
					<?php $response['domain_attachment_form'] = ob_get_clean();
				}
				else {
					ob_start() ?>
                    <div class="whcom_text_center whcom_margin_bottom_15 whcom_text_danger whcom_text_2x">
                        <strong><?php echo $domain_name ?><?php echo $domain_ext ?></strong> <?php esc_html_e( 'is unavailable', "whcom" ) ?>
                    </div>
					<?php $response['message'] = ob_get_clean();
				}
				break;
			}
		case 'transfer' :
			{
				if ( $response['status'] == 'OK' ) {
					ob_start() ?>
                    <div class="whcom_alert whcom_alert_success whcom_text_center whcom_margin_bottom_15">
                        <div class="whcom_margin_bottom_15 whcom_text_success whcom_text_2x">
							<?php esc_html_e( 'Your domain is eligible for transfer!', "whcom" ) ?>
                        </div>
						<?php esc_html_e( 'Please ensure you have unlocked your domain at your current registrar before continuing.', "whcom" ) ?>
                    </div>
                    <div class="whcom_text_center whcom_margin_bottom_15">
						<?php esc_html_e( 'Transfer to us and extend by ', "whcom" ) ?>
						<?php echo $tld_price; ?>
                    </div>
                    <form class="wcop_attach_product_domain whcom_text_center_xs" method="post">
                        <input type="hidden" name="action" value="wcop_attach_product_domain">
                        <input type="hidden" name="cart_index" value="<?php echo $cart_index; ?>">
                        <input type="hidden" name="domain" value="<?php echo $domain_name . $domain_ext; ?>">
                        <input type="hidden" name="type" value="<?php echo $domain_type; ?>">
                        <input type="hidden" name="regperiod" value="<?php echo $domain_duration; ?>">
                        <button type="submit"><?php esc_html_e( 'Continue', "whcom" ) ?></button>
                    </form>
					<?php $response['domain_attachment_form'] = ob_get_clean();
				}
				else {
					ob_start() ?>
                    <div class="whcom_alert whcom_text_center">
                        <div class="whcom_margin_bottom_15 whcom_text_danger whcom_text_2x">
							<?php esc_html_e( 'Not Eligible for Transfer', "whcom" ) ?>
                        </div>
                        <div class="whcom_margin_bottom_15">
							<?php esc_html_e( 'The domain you entered does not appear to be registered.', "whcom" ) ?>
                        </div>
                        <div class="whcom_margin_bottom_15">
							<?php esc_html_e( 'If the domain was registered recently, you may need to try again later.', "whcom" ) ?>
                        </div>
                        <div class="whcom_margin_bottom_15">
							<?php esc_html_e( 'Alternatively, you can perform a search to register this domain.', "whcom" ) ?>
                        </div>
                    </div>
					<?php $response['message'] = ob_get_clean();
				}
				break;
			}
		case 'existing' :
			{
				ob_start() ?>
                <form class="wcop_attach_product_domain whcom_text_center_xs whcom_padding_15_0" method="post">
                    <input type="hidden" name="action" value="wcop_attach_product_domain">
                    <input type="hidden" name="cart_index" value="<?php echo $cart_index; ?>">
                    <input type="hidden" name="domain" value="<?php echo $domain_name . $domain_ext; ?>">
                    <input type="hidden" name="domaintype" value="<?php echo $domain_type; ?>">
                    <input type="hidden" name="regperiod" value="<?php echo $domain_duration; ?>">
                    <button type="submit"><?php esc_html_e( 'Continue', "whcom" ) ?></button>
                </form>
				<?php $response['domain_attachment_form'] = ob_get_clean();
				break;
			}
	}
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_check_product_domain', 'wcop_check_product_domain' );
add_action( 'wp_ajax_nopriv_wcop_check_product_domain', 'wcop_check_product_domain' );


// Attaching domain with product during product configuration
function wcop_attach_product_domain() {
	$response               = [
		'status'  => 'ERROR',
		'message' => esc_html__( "Something went wrong, reloading the page...", "whcom" ),
	];
	$cart_index             = ( isset( $_POST['cart_index'] ) && $_POST['cart_index'] > - 1 ) ? (int) $_POST['cart_index'] : '-1';
	$domain_name            = ( ! empty( $_POST['domain'] ) ) ? esc_attr( $_POST['domain'] ) : '';
	$domain_type            = ( ! empty( $_POST['domaintype'] ) ) ? esc_attr( $_POST['domaintype'] ) : '';
	$response['domaintype'] = $domain_type;
	if ( $domain_type == 'existing' ) {
		$response['domain_config_form'] = '<input type="hidden" name="attached_domain" value="yes">';
		$response['status']             = 'OK';
		$response['message']            = '<div class="whcom_alert whcom_alert_success">' . esc_html__( 'Domain is attached with product...', "whcom" ) . '</div>';
	}
	else {
		$response['domain_config_form'] = wcop_render_product_domain_config_fields( $domain_name, $domain_type, $cart_index );
		if ( $response['domain_config_form'] ) {
			$response['domain_config_form'] .= '<input type="hidden" name="attached_domain" value="yes">';
			$response['status']             = 'OK';
			$response['message']            = '<div class="whcom_alert whcom_alert_success">' . esc_html__( 'Domain is attached with product...', "whcom" ) . '</div>';
		}
	}
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_attach_product_domain', 'wcop_attach_product_domain' );
add_action( 'wp_ajax_nopriv_wcop_attach_product_domain', 'wcop_attach_product_domain' );

// Repopulating product options if billingcycle is changed...
function wcop_get_product_config_options() {
	$response     = [
		'status'  => 'ERROR',
		'message' => esc_html__( 'Something went wrong, kindly refresh the page', "whcom" )
	];
	$product_id   = ( ! empty( $_POST['product_id'] ) && $_POST['product_id'] > 0 ) ? $_POST['product_id'] : 0;
	$cart_index   = ( isset( $_POST['cart_index'] ) ) ? $_POST['cart_index'] : - 1;
	$billingcycle = ( ! empty( $_POST['billingcycle'] ) ) ? (string) $_POST['billingcycle'] : '';
	if ( $product_id > 0 ) {
		$response['status']       = 'OK';
		$response['options_html'] = whcom_render_product_config_options( $product_id, $cart_index, $billingcycle );
		$response['message']      = esc_html__( 'Repopulating product options', "whcom" );
	}
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_get_product_config_options', 'wcop_get_product_config_options' );
add_action( 'wp_ajax_nopriv_wcop_get_product_config_options', 'wcop_get_product_config_options' );

// Adding the product to cart after user completes the configuration and press "Add to cart" button
function wcop_add_product_to_cart() {
	$response = [
		'status'  => 'ERROR',
		'message' => esc_html__( 'Something went wrong, kindly refresh the page', "whcom" )
	];
	if ( ! empty ( $_POST ) && ! empty ( $_POST['required_domain'] ) ) {
		if ( $_POST['required_domain'] == 'yes' && empty( $_POST['attached_domain'] ) ) {
			$response = [
				'status'  => 'ERROR',
				'message' => esc_html__( 'Domain is required with this package, kindly attach a domain using above options', "whcom" )
			];
		}
		else {
			$response = whcom_add_update_cart_item( $_POST );
		}
	}
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_add_product_to_cart', 'wcop_add_product_to_cart' );
add_action( 'wp_ajax_nopriv_wcop_add_product_to_cart', 'wcop_add_product_to_cart' );


// Summary functions start from here...
function wcop_generate_current_product_summery() {
	$response   = [
		'status'  => 'ERROR',
		'message' => esc_html__( 'Something went wrong, kindly refresh the page', "whcom" )
	];
	$product_id = ( ! empty( $_POST['pid'] ) && $_POST['pid'] > 0 ) ? $_POST['pid'] : 0;
	if ( $product_id > 0 ) {
		$response['summary_html'] = wcop_generate_current_product_summery_function( $_POST );
		$response['post']         = $_POST;
		$response['status']       = 'OK';
		$response['message']      = esc_html__( 'Repopulating product Summary', "whcom" );
	}
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_generate_current_product_summery', 'wcop_generate_current_product_summery' );
add_action( 'wp_ajax_nopriv_wcop_generate_current_product_summery', 'wcop_generate_current_product_summery' );


function wcop_generate_cart_summaries() {
	$response = [
		'status'  => 'ERROR',
		'message' => esc_html__( 'Something went wrong, kindly refresh the page', "whcom" )
	];
	$response = wcop_generate_summery();
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_generate_cart_summaries', 'wcop_generate_cart_summaries' );
add_action( 'wp_ajax_nopriv_wcop_generate_cart_summaries', 'wcop_generate_cart_summaries' );


// Client functions start from here...
function wcop_client_login() {
	$response = [
		'status'  => 'ERROR',
		'message' => esc_html__( 'Something went wrong, kindly refresh the page', "whcom" )
	];
	if ( ! empty( $_POST ) ) {
		$response = whcom_validate_client( $_POST );
	}
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_client_login', 'wcop_client_login' );
add_action( 'wp_ajax_nopriv_wcop_client_login', 'wcop_client_login' );


function wcop_add_client() {
	$response = [
		'status'  => 'ERROR',
		'message' => esc_html__( 'Something went wrong, kindly refresh the page', "whcom" )
	];
	if ( ! empty( $_POST ) ) {
		$response = whcom_register_new_client( $_POST );
	}
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_add_client', 'wcop_add_client' );
add_action( 'wp_ajax_nopriv_wcop_add_client', 'wcop_add_client' );


// Cart related functions start from here...
function wcop_submit_order() {
	$response = [
		'status'  => 'ERROR',
		'message' => esc_html__( 'Something went wrong, kindly refresh the page', "whcom" )
	];
	if ( ! empty( $_POST ) ) {
		$response = whcom_add_update_cart_item( $_POST );
		if ( $response ) {
			$response = whcom_submit_order();
		}
		if ( ! empty( $response['result'] ) ) {
			if ( $response['result'] == 'success' ) {
				$response['status']        = 'OK';
				$response['message']       = esc_html__( 'Your product has been ordered...' );
				$response['redirect_link'] = $response['response_form'] = $response['invoice_link'] = $response['show_cc'] = '';
				$field                     = 'order_complete_redirect' . whcom_get_current_language();
				$response['redirect_link'] = '<a href="' . esc_attr( get_option( $field ) ) . '" class="whcom_button">' . esc_html__( 'Dashboard', "whcom" ) . '</a> ';
				if ( wcop_use_merchant_gateway() && ( esc_attr( $_POST['paymentmethod'] ) == get_option( 'merchant_gateway_key', '' ) ) ) {
					$response['show_cc'] = 'yes';
					ob_start(); ?>
                    <form class="wcop_capture_invoice_payment" method="post">
                        <input type="hidden" name="action" value="wcop_capture_invoice_payment">
                        <input type="hidden" name="invoiceid" value="<?php echo $response['invoiceid']; ?>">
						<?php echo whcom_render_cc_form(); ?>
                        <div class="wcop_response"></div>
                        <div class="whcom_form_field whcom_text_center">
                            <button type="submit"><?php esc_html_e( 'Pay Invoice', "whcom" ) ?></button>
                        </div>
                    </form>
					<?php
					$response['response_form'] = ob_get_clean();
				}
				else {
					# Generate AutoAuth URL & Redirect
					$args = [
						'goto' => "viewinvoice.php?wcap_no_redirect=1&id=" . $response['invoiceid'],
					];
					$url  = whcom_generate_auto_auth_link( $args );

					if ( get_option( 'wcop_show_invoice_as', 'popup' ) == 'popup' ) {
						$redirect_link            = '<a class="whcom_op_thickbox_redirect_overlay" href="' . get_option( 'order_complete_redirect' . whcom_get_current_language(), '#' ) . '">' . esc_html__( 'Close', "whcom" ) . '</a> ';
						$invoice_div              = '<div id="invoice_' . $response['invoiceid'] . '" style="display:none;"><iframe style="width: 100%; height: 100%; overflow: auto;" src="' . $url . '"></iframe>' . $redirect_link . '</div>';
						$invoice_anchor           = '<a href="#TB_inline?width=850&height=550&inlineId=invoice_' . $response['invoiceid'] . '" class="thickbox whcom_button wcop_view_invoice_button">' . esc_html__( 'View Invoice', "whcom" ) . '</a> ';
						$response['invoice_link'] = $invoice_anchor . $invoice_div;
					}
					else {
						$response['invoice_link'] = '<a target="_blank" href="?a=viewinvoice&id=' . $response['invoiceid'] . '" class="whcom_button wcop_view_invoice_button">' . esc_html__( 'View Invoice', "whcom" ) . '</a> ';
					}

					$response['response_html'] = '<div class="whcom_alert whcom_alert_success whcom_max_width_640 whcom_margin_bottom_45">' . esc_html__( "We have received your order, please proceed with payment or return to dashboard. ", "whcom" ) . '</div>';
				}
			}
			else {
				$response['status'] = 'ERROR';
			}
		}
	}
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_submit_order', 'wcop_submit_order' );
add_action( 'wp_ajax_nopriv_wcop_submit_order', 'wcop_submit_order' );

function wcop_capture_invoice_payment() {
	$_POST['clientid'] = whcom_get_current_client_id();
	$_POST['expdate']  = esc_attr( $_POST['exp_month'] ) . esc_attr( $_POST['exp_year'] );
	$response          = wcop_capture_payment_function( $_POST );

	if ( $response['status'] == 'OK' ) {
		$dashboard_url = '';
		$field         = 'order_complete_redirect' . whcom_get_current_language();
		$dashboard_url = esc_attr( get_option( $field, home_url() ) );
		ob_start();

		?>
        <div class="whcom_form_field">
			<?php esc_html_e( 'Thank you for your order. You will receive a confirmation email shortly.', "whcom" ) ?>
        </div>
        <div class="whcom_alert whcom_alert_info">
            <span><?php esc_html_e( 'Your invoice ID is: ', "whcom" ) ?></span><?php echo $_POST['invoiceid'] ?>
        </div>
        <div class="whcom_form_field">
			<?php esc_html_e( 'If you have any questions about your order, please open a support ticket from your client area and quote your order number.', "whcom" ) ?>
        </div>

        <div class="whcom_form_field whcom_text_center">
            <a href="<?php echo $dashboard_url ?>"
               class="whcom_button whcom_button_secondary"><?php esc_html_e( 'Continue To Client Area', "whcom" ) ?></a>
        </div>

		<?php
		$response['response_html'] = ob_get_clean();
	}
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_capture_invoice_payment', 'wcop_capture_invoice_payment' );
add_action( 'wp_ajax_nopriv_wcop_capture_invoice_payment', 'wcop_capture_invoice_payment' );

function wcop_delete_cart_item() {
	$cart_index = esc_attr( $_POST['cart_index'] );
	$response   = whcom_delete_cart_item( $cart_index );
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_delete_cart_item', 'wcop_delete_cart_item' );
add_action( 'wp_ajax_nopriv_wcop_delete_cart_item', 'wcop_delete_cart_item' );

function wcop_reset_cart() {
	whcom_reset_cart();
	$response = [
		'status'  => "OK",
		'message' => esc_html__( 'Cart is emptied, reloading the page', "whcom" ),
	];
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_reset_cart', 'wcop_reset_cart' );
add_action( 'wp_ajax_nopriv_wcop_reset_cart', 'wcop_reset_cart' );


// Single Page (template) functions start from here
function wcop_sp_process() {
	$wcop_what        = ( ! empty( $_POST['wcop_sp_what'] ) ) ? esc_attr( $_POST['wcop_sp_what'] ) : 'nothing';
	$response         = [];
	$response['post'] = $_POST;
	switch ( $wcop_what ) {
		case 'check_domain' :
			{
				$response    = whcom_check_domain_function( $_POST );
				$cart_index  = ( isset( $_POST['cart_index'] ) && $_POST['cart_index'] > - 1 ) ? (int) $_POST['cart_index'] : '-1';
				$domain_ext  = ( ! empty( $_POST['ext'] ) ) ? esc_attr( $_POST['ext'] ) : '';
				$domain_name = ( ! empty( $_POST['domain'] ) ) ? esc_attr( $_POST['domain'] ) : '';
				$domain_type = ( ! empty( $_POST['domaintype'] ) ) ? esc_attr( $_POST['domaintype'] ) : '';


				$tld_details = whcom_get_tld_details( $domain_ext );
				$tld_price   = '';
				if ( ! empty( $tld_details[ $domain_type . '_price' ] ) ) {
					foreach ( $tld_details[ $domain_type . '_price' ] as $dur => $price ) {
						if ( $price >= 0 ) {
							$tld_price = (string) $dur . ' ';
							$tld_price .= ( $dur == 1 ) ? esc_html__( ' Year', "whcom" ) : esc_html__( ' Years', "whcom" );
							$tld_price .= esc_html__( ' for ', "whcom" );
							$tld_price .= whcom_format_amount( [ 'amount' => $price, 'add_suffix' => 'yes' ] );
							break;
						}
					}
				}
				$response['domaintype'] = $domain_type;
				switch ( $domain_type ) {
					case 'register' :
						{
							if ( $response['status'] == 'OK' ) {
								ob_start() ?>
                                <div class="whcom_text_center whcom_text_success whcom_text_2x">
									<?php esc_html_e( 'Congratulations!', "whcom" ) ?>
                                    <strong><?php echo $domain_name ?><?php echo $domain_ext ?></strong> <?php esc_html_e( 'is available!', "whcom" ) ?>
                                </div>
                                <div class="whcom_text_center whcom_margin_bottom_15">
									<?php esc_html_e( 'Continue to register this domain for ', "whcom" ) ?>
									<?php echo $tld_price; ?>
                                </div>
                                <form class="wcop_sp_attach_product_domain whcom_text_center_xs" method="post">
                                    <input type="hidden" name="action" value="wcop_sp_process">
                                    <input type="hidden" name="wcop_sp_what" value="attach_domain">
                                    <input type="hidden" name="cart_index" value="<?php echo $cart_index; ?>">
                                    <input type="hidden" name="domain"
                                           value="<?php echo $domain_name . $domain_ext; ?>">
                                    <input type="hidden" name="type" value="<?php echo $domain_type; ?>">
                                    <button type="submit" class="whcom_button whcom_button_success">
                                        <strong><?php esc_html_e( 'Continue', "whcom" ) ?></strong></button>
                                </form>
								<?php $response['domain_attachment_form'] = ob_get_clean();
							}
							else {
								ob_start() ?>
                                <div class="whcom_text_center whcom_margin_bottom_15 whcom_text_danger whcom_text_2x">
                                    <strong><?php echo $domain_name ?><?php echo $domain_ext ?></strong> <?php esc_html_e( 'is unavailable', "whcom" ) ?>
                                </div>
								<?php $response['message'] = ob_get_clean();
							}
							break;
						}
					case 'transfer' :
						{
							if ( $response['status'] == 'OK' ) {
								ob_start() ?>
                                <div class="whcom_alert whcom_alert_success whcom_text_center whcom_margin_bottom_15">
                                    <div class="whcom_margin_bottom_15 whcom_text_success whcom_text_2x">
										<?php esc_html_e( 'Your domain is eligible for transfer!', "whcom" ) ?>
                                    </div>
									<?php esc_html_e( 'Please ensure you have unlocked your domain at your current registrar before continuing.', "whcom" ) ?>
                                </div>
                                <div class="whcom_text_center whcom_margin_bottom_15">
									<?php esc_html_e( 'Transfer to us and extend by ', "whcom" ) ?>
									<?php echo $tld_price; ?>
                                </div>
                                <form class="wcop_sp_attach_product_domain whcom_text_center_xs" method="post">
                                    <input type="hidden" name="action" value="wcop_sp_process">
                                    <input type="hidden" name="wcop_sp_what" value="attach_domain">
                                    <input type="hidden" name="cart_index" value="<?php echo $cart_index; ?>">
                                    <input type="hidden" name="domain"
                                           value="<?php echo $domain_name . $domain_ext; ?>">
                                    <input type="hidden" name="type" value="<?php echo $domain_type; ?>">
                                    <button type="submit" class="whcom_button whcom_button_success">
                                        <strong><?php esc_html_e( 'Continue', "whcom" ) ?></strong></button>
                                </form>
								<?php $response['domain_attachment_form'] = ob_get_clean();
							}
							else {
								ob_start() ?>
                                <div class="whcom_alert whcom_text_center">
                                    <div class="whcom_margin_bottom_15 whcom_text_danger whcom_text_2x">
										<?php esc_html_e( 'Not Eligible for Transfer', "whcom" ) ?>
                                    </div>
                                    <div class="whcom_margin_bottom_15">
										<?php esc_html_e( 'The domain you entered does not appear to be registered.', "whcom" ) ?>
                                    </div>
                                    <div class="whcom_margin_bottom_15">
										<?php esc_html_e( 'If the domain was registered recently, you may need to try again later.', "whcom" ) ?>
                                    </div>
                                    <div class="whcom_margin_bottom_15">
										<?php esc_html_e( 'Alternatively, you can perform a search to register this domain.', "whcom" ) ?>
                                    </div>
                                </div>
								<?php $response['message'] = ob_get_clean();
							}
							break;
						}
					case 'existing' :
						{
							ob_start() ?>
                            <form class="wcop_sp_attach_product_domain whcom_text_center_xs" method="post">
                                <input type="hidden" name="action" value="wcop_sp_process">
                                <input type="hidden" name="wcop_sp_what" value="attach_domain">
                                <input type="hidden" name="cart_index" value="<?php echo $cart_index; ?>">
                                <input type="hidden" name="domain" value="<?php echo $domain_name . $domain_ext; ?>">
                                <input type="hidden" name="type" value="<?php echo $domain_type; ?>">
                                <button type="submit" class="whcom_button whcom_button_success">
                                    <strong><?php esc_html_e( 'Continue', "whcom" ) ?></strong></button>
                            </form>
							<?php $response['domain_attachment_form'] = ob_get_clean();
							break;
						}
				}
				break;
			}
		case 'attach_domain' :
			{
				$response    = [
					'status'  => 'ERROR',
					'message' => esc_html__( "Something went wrong, reloading the page...", "whcom" ),
				];
				$cart_index  = ( isset( $_POST['cart_index'] ) && $_POST['cart_index'] > - 1 ) ? (int) $_POST['cart_index'] : '-1';
				$domain_name = ( ! empty( $_POST['domain'] ) ) ? esc_attr( $_POST['domain'] ) : '';
				$domain_type = ( ! empty( $_POST['domaintype'] ) ) ? esc_attr( $_POST['domaintype'] ) : '';
				if ( $domain_type == 'existing' ) {
					$response['domain_config_form'] = '<input type="hidden" name="attached_domain" value="yes">';
					$response['status']             = 'OK';
					$response['message']            = '<div class="whcom_alert whcom_alert_success">' . esc_html__( 'Domain is attached with product...', "whcom" ) . '</div>';
				}
				else {
					$response['domain_config_form'] = wcop_render_product_domain_config_fields( $domain_name, $domain_type, $cart_index );
					if ( $response['domain_config_form'] ) {
						$response['domain_config_form'] .= '<input type="hidden" name="attached_domain" value="yes">';
						$response['status']             = 'OK';
						$response['message']            = '<div class="whcom_alert whcom_alert_success">' . esc_html__( 'Domain is attached with product...', "whcom" ) . '</div>';
					}
				}
				$response['added_button'] = '<button disabled="disabled" class="whcom_button whcom_button_success">' . esc_html__( "Added", "whcom" ) . '</button>';
				break;
			}
		case 'change_product' :
			{
				if ( ! empty( $_POST['pid'] ) ) {
					$product_details = whcom_get_product_details( (int) $_POST['pid'] );
					if ( ( empty( $billing_cycle ) ) && ( ! empty( $product_details['lowest_price'] ) ) ) {
						reset( $product_details['lowest_price'] );
						$billing_cycle = key( $product_details['lowest_price'] );
					}
					$free_domain_billingcycles = [];
					if ( ! empty ( $product_details['freedomainpaymentterms'] ) ) {
						$free_domain_billingcycles = explode( ',', $product_details['freedomainpaymentterms'] );
					}
					if ( $product_details ) {
						$response['status'] = 'OK';
						ob_start(); ?>
						<?php if ( $product_details['paytype'] == 'recurring' ) { ?>
                            <div class="wcop_sp_product_billingcycle whcom_form_field whcom_form_field_horizontal">
								<?php $all_prices = $product_details['all_prices']; ?>
								<?php
								$billing_cycle_class = 'wcop_form_control wcop_input';
								if ( ! empty( $product_details['prd_configoptions'] ) ) {
									$billing_cycle_class .= ' wcop_update_product_options';
								}
								?>
                                <label for="wcop_sp_product_billingcycle"
                                       class="main_label"><?php echo esc_html__( 'Choose Billing Cycle', "whcom" ) . ": " ?></label>
                                <select id="wcop_sp_product_billingcycle"
                                        name="billingcycle"
                                        class="<?php echo $billing_cycle_class ?> wcop_input">
									<?php $current = '';
									foreach ( $all_prices as $key => $price ) {
										( $billing_cycle == $key ) ? $current = 'selected' : $current = '';
										$option_string = '<option value="' . $key . '" ' . $current . '>';
										$option_string .= whcom_format_amount( [ 'amount' => $price['price'] ] ) . ' ' . whcom_convert_billingcycle( $key ) . ' + ' . whcom_format_amount( [ 'amount' => $price['setup'] ] ) . ' ' . esc_html__( 'Setup Fee', "whcom" );
										if ( in_array( $key, $free_domain_billingcycles ) ) {
											$option_string .= ' (' . esc_html__( 'Free Domain', "whcom" ) . ') ';
										}
										$option_string .= '</option>';
										echo $option_string;
									}
									?>
                                </select>
                            </div>
						<?php } ?>
						<?php if ( $product_details['paytype'] == 'free' ) { ?>
                            <input type="hidden" name="billingcycle" value="<?php echo $billing_cycle ?>">
						<?php } ?>
						<?php if ( $product_details['paytype'] == 'onetime' ) { ?>
                            <input type="hidden" name="billingcycle" value="<?php echo $billing_cycle ?>">
						<?php } ?>
                        <div class="wcop_sp_free_tlds_info">
							<?php if ( ! empty( $product_details['freedomainpaymentterms'] ) && ! empty( $product_details['freedomaintlds'] ) ) { ?>
                                <div class="whcom_alert whcom_alert_info">
                                    <div>
										<?php esc_html_e( 'Free Domain is only available for following TLD\'s', "whcom" ) ?>
                                    </div>
                                    <div><strong><?php echo $product_details['freedomaintlds']; ?></strong>
                                    </div>
                                </div>
                                <div class="whcom_alert whcom_alert_info">
                                    <div>
										<?php esc_html_e( 'Free Domain is only available for following billingcycles...', "whcom" ) ?>
                                    </div>
                                    <div>
                                        <strong><?php echo $product_details['freedomainpaymentterms']; ?></strong>
                                    </div>
                                </div>
							<?php } ?>
                        </div>
						<?php $response['billingcycle_html'] = ob_get_clean();

						ob_start(); ?>
                        <div class="wcop_sp_server_options_container wcop_sp_product_config_block">
							<?php if ( $product_details['type'] == 'server' ) { ?>
								<?php echo whcom_render_server_specific_fields(); ?>
							<?php } ?>
                        </div>
                        <div class="wcop_sp_config_options_container wcop_sp_product_config_block">
							<?php if ( ! empty( $product_details['prd_configoptions'] ) ) { ?>
								<?php echo whcom_render_product_config_options( $product_details, - 1, $billing_cycle ) ?>
							<?php } ?>
                        </div>
                        <div class="wcop_sp_custom_options_container wcop_sp_product_config_block">
							<?php if ( ! empty( $product_details['custom_fields'] ) && is_array( $product_details['custom_fields'] ) ) { ?>
                                <div class="whcom_collapse active">
                                    <div data-collapse="whcom_sp_custom_options" class="whcom_collapse_toggle">
                                        <span><?php esc_html_e( 'Additional Required Information', "whcom" ) ?></span>
                                    </div>
                                    <div id="whcom_sp_custom_options" class="whcom_collapse_content">
										<?php echo whcom_render_product_custom_fields( $product_details ); ?>
                                    </div>
                                </div>
							<?php } ?>
                        </div>
                        <div class="wcop_sp_addons_options_container wcop_sp_product_config_block">
							<?php if ( ! empty( $product_details['prd_addons'] ) && is_array( $product_details['prd_addons'] ) ) { ?>
                                <div class="whcom_collapse active">
                                    <div data-collapse="whcom_sp_addons_options" class="whcom_collapse_toggle">
                                        <span><?php esc_html_e( 'Available Addons', "whcom" ) ?></span>
                                    </div>
                                    <div id="whcom_sp_addons_options" class="whcom_collapse_content">
										<?php echo whcom_render_product_addons( $product_details ); ?>
                                    </div>
                                </div>
							<?php } ?>
                        </div>
						<?php $response['options_html'] = ob_get_clean();
					}
					else {
						$response['message'] = esc_html__( "Wrong Product ID provided", "whcom" );
						$response['status']  = 'ERROR';
					}
				}
				else {
					$response['message'] = esc_html__( "Wrong Product ID provided", "whcom" );
					$response['status']  = 'ERROR';
				}

				break;
			}
		case 'change_billingcycle' :
			{
				if ( ! empty( $_POST['pid'] ) ) {
					$billing_cycle   = esc_attr( $_POST['billingcycle'] );
					$product_details = whcom_get_product_details( (int) $_POST['pid'] );
					if ( ( empty( $billing_cycle ) ) && ( ! empty( $product_details['lowest_price'] ) ) ) {
						reset( $product_details['lowest_price'] );
						$billing_cycle = key( $product_details['lowest_price'] );
					}
					if ( $product_details ) {
						$response['status'] = 'OK';
						ob_start();
						if ( ! empty( $product_details['prd_configoptions'] ) ) {
							echo whcom_render_product_config_options( $product_details, - 1, $billing_cycle );
						}
						$response['options_html'] = ob_get_clean();
					}
					else {
						$response['message'] = esc_html__( "Wrong Product ID provided", "whcom" );
						$response['status']  = 'ERROR';
					}
				}
				else {
					$response['message'] = esc_html__( "Wrong Product ID provided", "whcom" );
					$response['status']  = 'ERROR';
				}

				break;
			}
		case 'wcop_sp_generate_summary' :
			{
				$product_id = ( ! empty( $_POST['pid'] ) && $_POST['pid'] > 0 ) ? $_POST['pid'] : 0;
				if ( $product_id > 0 ) {
					$response['summary_html'] = wcop_generate_current_product_summery_function( $_POST );
					$response['status']       = 'OK';
					$response['message']      = esc_html__( 'Repopulating product options', "whcom" );
				}
				break;
			}


		case 'add_order' :
			{
				$client_id      = false;
				$product_fields = ( empty( $_POST['customfields'] ) ) ? [] : $_POST['customfields'];
				$client_fields  = ( empty( $_POST['client_customfields'] ) ) ? [] : $_POST['client_customfields'];


				if ( whcom_is_client_logged_in() ) {
					$client_id           = whcom_get_current_client_id();
					$response['message'] = esc_html__( "Client is already logged in", "whcom" );
				}
				else {
					// Validate/Register Client
					if ( ! empty( $_POST['wcop_sp_client_type'] ) ) {
						if ( esc_attr( $_POST['wcop_sp_client_type'] ) == 'register' ) {
							$response['message']   = esc_html__( "Registering New Client", "whcom" );
							$_POST['customfields'] = $client_fields;
							$temp_response         = whcom_register_new_client( $_POST );
							if ( $temp_response['status'] == 'OK' ) {
								$client_id = whcom_get_current_client_id();
							}
							else {
								$response = $temp_response;
							}
						}
						else {
							$response['message'] = esc_html__( "Validating Client", "whcom" );
							$credentials         = [
								'email' => ( ! empty( $_POST['login_email'] ) ) ? esc_attr( $_POST['login_email'] ) : '',
								'pass'  => ( ! empty( $_POST['login_pass'] ) ) ? esc_attr( $_POST['login_pass'] ) : '',
							];
							$temp_response       = whcom_validate_client( $credentials );
							$response['rrcit']   = $temp_response;
							if ( $temp_response['status'] == 'OK' ) {
								$client_id = whcom_get_current_client_id();
							}
							else {
								$response = $temp_response;
							}
						}
					}
				}


				// Add Order
				if ( $client_id && (int) $client_id > 0 ) {
					$_POST['customfields'] = $product_fields;
					$response              = whcom_add_update_cart_item( $_POST );
					if ( $response['status'] == 'OK' ) {
						$response = whcom_submit_order();
						if ( ! empty( $response['result'] ) ) {
							if ( $response['result'] == 'success' ) {
								$response['status']        = 'OK';
								$response['message']       = esc_html__( 'Your product has been ordered...' );
								$response['redirect_link'] = $response['response_form'] = $response['invoice_link'] = $response['show_cc'] = '';
								$field                     = 'order_complete_redirect' . whcom_get_current_language();
								$response['redirect_link'] = '<a href="' . esc_attr( get_option( $field ) ) . '" class="whcom_button">' . esc_html__( 'Dashboard', "whcom" ) . '</a> ';
								if ( wcop_use_merchant_gateway() && ( esc_attr( $_POST['paymentmethod'] ) == get_option( 'merchant_gateway_key', '' ) ) ) {

									$_POST['invoiceid'] = $response['invoiceid'];
									$_POST['clientid']  = whcom_get_current_client_id();
									$_POST['expdate']   = esc_attr( $_POST['exp_month'] ) . esc_attr( $_POST['exp_year'] );
									$response           = wcop_capture_payment_function( $_POST );

									if ( $response['status'] == 'OK' ) {
										$field         = 'order_complete_redirect' . whcom_get_current_language();
										$dashboard_url = esc_attr( get_option( $field, home_url() ) );
										ob_start();

										?>
                                        <div class="whcom_form_field">
											<?php esc_html_e( 'Thank you for your order. You will receive a confirmation email shortly.', "whcom" ) ?>
                                        </div>
                                        <div class="whcom_alert whcom_alert_info">
                                            <span><?php esc_html_e( 'Your invoice ID is: ', "whcom" ) ?></span><?php echo $_POST['invoiceid'] ?>
                                        </div>
                                        <div class="whcom_form_field">
											<?php esc_html_e( 'If you have any questions about your order, please open a support ticket from your client area and quote your order number.', "whcom" ) ?>
                                        </div>

                                        <div class="whcom_form_field whcom_text_center">
                                            <a href="<?php echo $dashboard_url ?>"
                                               class="whcom_button whcom_button_secondary"><?php esc_html_e( 'Continue To Client Area', "whcom" ) ?></a>
                                        </div>

										<?php
										$response['response_html'] = ob_get_clean();
									}
									$response['show_cc'] = 'html';
								}
								else {
									# Generate AutoAuth URL & Redirect
									$args = [
										'goto' => "viewinvoice.php?wcap_no_redirect=1&id=" . $response['invoiceid'],
									];
									$url  = whcom_generate_auto_auth_link( $args );


									if ( get_option( 'wcop_show_invoice_as', 'popup' ) == 'popup' ) {
										$redirect_link            = '<a class="wcop_thickbox_redirect_overlay" href="' . get_option( 'order_complete_redirect' . whcom_get_current_language(), '#' ) . '">' . esc_html__( 'Close', "whcom" ) . '</a> ';
										$invoice_div              = '<div id="invoice_' . $response['invoiceid'] . '" style="display:none;"><iframe style="width: 100%; height: 100%; overflow: auto;" src="' . $url . '"></iframe>' . $redirect_link . '</div>';
										$invoice_anchor           = '<a href="#TB_inline?width=1050&height=550&inlineId=invoice_' . $response['invoiceid'] . '" class="thickbox whcom_button wcop_view_invoice_button">' . esc_html__( 'View Invoice', "whcom" ) . '</a> ';
										$response['invoice_link'] = $invoice_anchor . $invoice_div;
									}
									else {
										$response['invoice_link'] = '<a target="_blank" href="' . $url . '" class="whcom_button wcop_view_invoice_button">' . esc_html__( 'View Invoice', "whcom" ) . '</a> ';
									}


									$response['show_cc'] = 'show_invoice';
									ob_start(); ?>
                                    <div style="padding: 6%; max-width: 680px; margin: 0 auto 40px">

                                        <div class="whcom_alert whcom_alert_success whcom_margin_bottom_45">
                                            <span><?php esc_html_e( "Your order has been placed, it will be activated once the invoice is paid. If you have just paid the invoice, ignore this message", "whcom" ); ?> </span>
                                        </div>

                                        <div class="whcom_row">
                                            <div class="whcom_col_sm_6 whcom_text_center whcom_text_right_sm whcom_margin_bottom_15">
												<?php echo $response['redirect_link']; ?>
                                            </div>
                                            <div class="whcom_col_sm_6 whcom_text_center whcom_text_left_sm whcom_margin_bottom_15">
												<?php echo $response['invoice_link']; ?>
                                            </div>
                                        </div>

                                    </div>

									<?php
									$response['response_html'] = ob_get_clean();
								}
							}
							else {
								$response['status'] = 'ERROR';
							}
						}
					}
				}


				// Invoice Actions


				break;
			}

		default :
			{
				$response['message'] = esc_html__( "Something went wrong, kindly try again later ...", "whcom" );
				$response['status']  = 'ERROR';
			}
	}


	if ( $response['status'] == 'OK' ) {
		$response['message'] = '<div class="whcom_alert whcom_alert_success">' . $response['message'] . '</div>';
	}
	else {
		$response['message'] = '<div class="whcom_alert whcom_alert_danger">' . $response['message'] . '</div>';
	}
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_sp_process', 'wcop_sp_process' );
add_action( 'wp_ajax_nopriv_wcop_sp_process', 'wcop_sp_process' );

// Domain First (template) functions start from here
function wcop_domain_first() {
	$wcop_what        = ( ! empty( $_POST['wcop_what'] ) ) ? esc_attr( $_POST['wcop_what'] ) : 'nothing';
	$response         = [];
	$response['post'] = $_POST;
	switch ( $wcop_what ) {
		case 'domain_search' :
			{
				$check_type = esc_attr( $_POST['domaintype'] );
				if ( $check_type == 'existing' ) {
					$response['message'] = esc_html__( "Selected existing domain, so not checking anything", "whcom" );
					$response['status']  = 'OK';
				}
				else {
					$gids                     = ( ! empty( $_REQUEST['gids'] ) ) ? esc_attr( $_REQUEST['gids'] ) : '';
					$pids                     = ( ! empty( $_REQUEST['pids'] ) ) ? esc_attr( $_REQUEST['pids'] ) : '';
					$domain                   = [
						'action' => 'DomainWhois',
						'domain' => esc_attr( $_POST['domain'] )
					];
					$res                      = whcom_process_api( $domain );
					$response['api_response'] = $res;
					if ( $res['result'] != 'success' ) {
						$response['message'] = $res['message'];
						$response['status']  = 'ERROR';
					}
					else {
						$response['status'] = 'OK';
						if ( $check_type == 'register' ) {
							if ( $res['status'] != 'available' ) {
								$response['message'] = esc_html__( 'Domain is not available for registration...' );
								$response['status']  = 'ERROR';
							}
							else {
								$response['response_form'] = '<span>' . esc_html__( 'Stake Your Claim !' ) . '</span>';
								$response['response_form'] .= '<form method="post" id="wcop_df_domain_search_submit" style="float: right">';
								$response['response_form'] .= '<input type="hidden" name="action" value="wcop_domain_first">';
								$response['response_form'] .= '<input type="hidden" name="wcop_what" value="domain_submit">';
								$response['response_form'] .= '<input type="hidden" name="domain" value="' . $domain['domain'] . '">';
								$response['response_form'] .= '<input type="hidden" name="pids" value="' . $pids . '">';
								$response['response_form'] .= '<input type="hidden" name="gids" value="' . $gids . '">';
								$response['response_form'] .= '<input type="hidden" name="type" value="register">';
								$response['response_form'] .= '<button type="submit">' . esc_html__( 'Continue', "whcom" ) . '</button>';
								$response['response_form'] .= '';
								$response['response_form'] .= '</form>';
								$response['response_form'] .= '<div style="clear: both"></div>';
								$response['message']       = esc_html__( 'Domain is available...' );
								$response['status']        = 'OK';
							}
						}
                        elseif ( $check_type == 'transfer' ) {
							if ( $res['status'] != 'available' ) {
								$response['response_form'] = '<span>' . esc_html__( 'Stake Your Claim !' ) . '</span>';
								$response['response_form'] .= '<form method="post" id="wcop_df_domain_search_submit" style="float: right">';
								$response['response_form'] .= '<input type="hidden" name="action" value="wcop_domain_first">';
								$response['response_form'] .= '<input type="hidden" name="wcop_what" value="domain_submit">';
								$response['response_form'] .= '<input type="hidden" name="domain" value="' . $domain['domain'] . '">';
								$response['response_form'] .= '<input type="hidden" name="pids" value="' . $pids . '">';
								$response['response_form'] .= '<input type="hidden" name="gids" value="' . $gids . '">';
								$response['response_form'] .= '<input type="hidden" name="type" value="transfer">';
								$response['response_form'] .= '<button type="submit">' . esc_html__( 'Transfer', "whcom" ) . '</button>';
								$response['response_form'] .= '';
								$response['response_form'] .= '</form>';
								$response['message']       = esc_html__( 'Yes, domain is registered, proceed with transfer' );
								$response['status']        = 'OK';
							}
							else {
								$response['message'] = esc_html__( 'Domain is not registered...' );
								$response['status']  = 'ERROR';
							}
						}
					}
				}
				break;
			}
		case 'domain_submit' :
			{
				$domain = whcom_get_domain_clean( esc_attr( $_POST['domain'] ) );
				if ( ( $domain == '' ) || ( $domain == '' ) ) {
					$response['message'] = esc_html__( "Domain was not selected properly, kindly try again...", "whcom" );
					$response['status']  = 'ERROR';
				}
				else {
					$tld             = whcom_get_tld_from_domain( $domain );
					$tld_det         = whcom_get_tld_details( $tld );
					$type            = esc_attr( $_POST['domaintype'] );
					$price_array     = $tld_det[ $type . '_price' ];
					$domain_duration = '1';
					if ( ! empty( $price_array ) ) {
						foreach ( $price_array as $y => $price ) {
							$domain_duration = $y;
							break;
						}
					}
					$item     = [
						'domain'     => $domain,
						'domaintype' => $type,
						'regperiod'  => $domain_duration,
					];
					$response = whcom_add_update_cart_item( $item );
					ob_start();
					include( WCOP_PATH . '/shortcodes/domain_first/style1/02_product.php' );
					$response['response_form'] = ob_get_clean();
					$response['message']       = esc_html__( "Loading Product Selection Form", "whcom" );
					$response['status']        = 'OK';
				}
				break;
			}
		case 'add_remove_domain' :
			{
				$domain_action   = esc_attr( $_POST['domain_action'] );
				$cart_index      = esc_attr( $_POST['cart_index'] );
				$domain_name     = esc_attr( $_POST['domain'] );
				$domain_type     = esc_attr( $_POST['domain_type'] );
				$domain_duration = esc_attr( $_POST['domain_duration'] );

				$item = [
					'domain'     => $domain_name,
					'domaintype' => $domain_type,
					'regperiod'  => $domain_duration,
				];
				if ( empty( $domain_duration ) || ( $domain_duration == "" ) ) {
					$response['status']  = "ERROR";
					$response['message'] = esc_html__( 'Sorry! This domain can not be added to cart at the moment', "whcom" );
				}
				else {
					if ( $domain_action == 'add_item' ) {
						$cart_items      = whcom_get_cart()['all_items'];
						$already_in_cart = false;
						foreach ( $cart_items as $key => $cart_item ) {
							if ( ( ! empty( $cart_item['domain'] ) ) && ( $cart_item['domain'] == $item['domain'] ) ) {
								$response['cart_index']    = $key;
								$response['status']        = "OK";
								$response['already_added'] = "YES";
								$already_in_cart           = true;
								break;
							}
						}
						if ( ! $already_in_cart ) {
							$response = whcom_add_update_cart_item( $item );
						}
						if ( $response['status'] == "OK" ) {
							$response['message'] = esc_html__( 'Domain is added to cart', "whcom" );
						}
					}
					else {
						$response = whcom_delete_cart_item( $cart_index );
						if ( $response['status'] == "OK" ) {
							$response['message'] = esc_html__( 'Domain is removed from cart', "whcom" );
						}
					}
				}

				$response['current_cart'] = whcom_get_cart();
				break;
			}
		case 'get_domain_products' :
			{
				ob_start();
				include( WCOP_PATH . '/shortcodes/domain_first/style1/02_products_list.php' );
				$response['products'] = ob_get_clean();
				$response['message']  = esc_html__( "Loading Product Selection Form", "whcom" );
				$response['status']   = 'OK';
				break;
			}
		case 'attach_domain_product' :
			{
				$product_action = esc_attr( $_POST['product_action'] );
				$pid            = esc_attr( $_POST['pid'] );
				$cid            = esc_attr( $_POST['cid'] );
				$cart_index     = esc_attr( $_POST['cart_index'] );
				$product_name   = esc_attr( $_POST['product_name'] );
				$product_price  = esc_attr( $_POST['product_price'] );
				$product_setup  = esc_attr( $_POST['product_setup'] );
				$billingcycle   = esc_attr( $_POST['billingcycle'] );

				$item = [
					'pid'                     => $pid,
					'cid'                     => $cid,
					'billingcycle'            => $billingcycle,
					'ps_product_name'         => $product_name,
					'ps_product_price'        => $product_price,
					'ps_product_setup'        => $product_setup,
					'ps_product_billingcycle' => $billingcycle,
				];
				if ( empty( $billingcycle ) || ( $billingcycle == "" ) ) {
					$response['status']  = "ERROR";
					$response['message'] = esc_html__( 'Sorry! This product can not be added to cart at the moment', "whcom" );
				}
				else {
					if ( $product_action == 'add_item' ) {
						$cart_items      = whcom_get_cart()['all_items'];
						$already_in_cart = false;
						if ( ( ! empty( $cart_items[ $cart_index ]['pid'] ) ) && ( $item['pid'] == $cart_items[ $cart_index ]['pid'] ) ) {
							$response['status']        = "OK";
							$response['already_added'] = "YES";
							$already_in_cart           = true;
						}
						if ( ! $already_in_cart ) {
							$response = whcom_add_update_cart_item( $item, $cart_index );
						}
						if ( $response['status'] == "OK" ) {
							$response['message'] = esc_html__( 'Product is attached with domain', "whcom" );
						}
					}
					else {
						$item     = [
							'pid'                     => "to_unset_string",
							'billingcycle'            => "to_unset_string",
							'ps_product_name'         => "to_unset_string",
							'ps_product_price'        => "to_unset_string",
							'ps_product_setup'        => "to_unset_string",
							'ps_product_billingcycle' => "to_unset_string",
						];
						$response = whcom_add_update_cart_item( $item, $cart_index );
						if ( $response['status'] == "OK" ) {
							$response['message'] = esc_html__( 'Product is detached from domain', "whcom" );
						}
					}
				}

				$response['item']         = $item;
				$response['current_cart'] = whcom_get_cart();
				break;
			}
		case 'domain_products_attached' :
			{
				if ( whcom_is_client_logged_in() ) {
					ob_start();
					include( WCOP_PATH . '/shortcodes/domain_first/style1/03_contact.php' );
					$response['response_form'] = ob_get_clean();
					$response['message']       = esc_html__( "Loading Contact Form", "whcom" );
					$response['status']        = 'OK';
				}
				else {
					ob_start();
					include( WCOP_PATH . '/shortcodes/domain_first/style1/03_client.php' );
					$response['response_form'] = ob_get_clean();
					$response['message']       = esc_html__( "Loading Client Form", "whcom" );
					$response['status']        = 'OK';
				}
				break;
			}
		case 'domains_config' :
			{
				//$response[''];
				$domain_fields    = $_POST['domainfields'];
				$domain_durations = $_POST['domainduration'];
				$domainns1        = $_POST['domainns1'];
				$domainns2        = $_POST['domainns2'];
				$domainns3        = $_POST['domainns3'];
				$domainns4        = $_POST['domainns4'];
				$domainns5        = $_POST['domainns5'];

				$response['ns_response'] = whcom_add_update_cart_item( [
					'domainns1' => $domainns1,
					'domainns2' => $domainns2,
					'domainns3' => $domainns3,
					'domainns4' => $domainns4,
					'domainns5' => $domainns5,
				], 0 );
				foreach ( $domain_fields as $cart_index => $domain_field ) {
					$response['df_response'][] = whcom_add_update_cart_item( [ 'domainfields' => $domain_field ], $cart_index );
				}
				foreach ( $domain_durations as $cart_index => $domain_duration ) {
					$response['dp_response'][] = whcom_add_update_cart_item( [ 'regperiod' => (int) $domain_duration ], $cart_index );
				}
				ob_start();
				include( WCOP_PATH . '/shortcodes/domain_first/style1/05_products_config.php' );
				$response['response_form'] = ob_get_clean();
				$response['current_cart']  = whcom_get_cart();
				$response['message']       = esc_html__( "Loading Client Form", "whcom" );
				$response['status']        = 'OK';
				break;
			}
		case 'client_login' :
			{
				$response = whcom_validate_client( $_POST );
				ob_start();
				include( WCOP_PATH . '/shortcodes/domain_first/style1/03_contact.php' );
				$response['response_form'] = ob_get_clean();
				break;
			}
		case 'client_register' :
			{
				$response = whcom_register_new_client( $_POST );
				ob_start();
				include( WCOP_PATH . '/shortcodes/domain_first/style1/03_contact.php' );
				$response['response_form'] = ob_get_clean();
				break;
			}
		case 'contact_add' :
			{
				$response = wcop_add_client_contact( $_POST );
				ob_start();
				$contact_type = 'registrant';
				include( WCOP_PATH . '/shortcodes/domain_first/style1/03_contacts_list.php' );
				$response['response_form_registrant'] = ob_get_clean();
				ob_start();
				$contact_type = 'admin';
				include( WCOP_PATH . '/shortcodes/domain_first/style1/03_contacts_list.php' );
				$response['response_form_admin'] = ob_get_clean();
				ob_start();
				$contact_type = 'tech';
				include( WCOP_PATH . '/shortcodes/domain_first/style1/03_contacts_list.php' );
				$response['response_form_tech'] = ob_get_clean();
				ob_start();
				$contact_type = 'billing';
				include( WCOP_PATH . '/shortcodes/domain_first/style1/03_contacts_list.php' );
				$response['response_form_billing'] = ob_get_clean();
				$response['message']               = esc_html__( "Loading Product Selection Form", "whcom" );
				$response['status']                = 'OK';
				break;
			}
		case 'contact_select' :
			{
				ob_start();
				include( WCOP_PATH . '/shortcodes/domain_first/style1/04_domains_config.php' );
				$response['response_form'] = ob_get_clean();
				$response['message']       = esc_html__( "Loading Product Selection Form", "whcom" );
				$response['status']        = 'OK';
				break;
			}
		case 'get_product_options' :
			{
				$billingcycle = esc_attr( $_POST['billingcycle'] );
				$cart_index   = esc_attr( $_POST['cart_index'] );
				$product_id   = esc_attr( $_POST['product_id'] );

				$response['status']        = "OK";
				$response['response_form'] = whcom_render_product_config_options( $product_id, $cart_index, $billingcycle );
				break;
			}
		case 'products_config' :
			{
				$product_durations = $_POST['billingcycle'];
				$product_options   = $_POST['configoptions'];
				$product_addons    = $_POST['addons'];
				$product_fields    = $_POST['customfields'];
				$domainns1         = $_POST['domainns1'];
				$domainns2         = $_POST['domainns2'];
				$domainns3         = $_POST['domainns3'];
				$domainns4         = $_POST['domainns4'];
				$domainns5         = $_POST['domainns5'];

				$response['ns_response'] = whcom_add_update_cart_item( [
					'domainns1' => $domainns1,
					'domainns2' => $domainns2,
					'domainns3' => $domainns3,
					'domainns4' => $domainns4,
					'domainns5' => $domainns5,
				], 0 );
				foreach ( $product_durations as $cart_index => $product_duration ) {
					$response['pd_response'][] = whcom_add_update_cart_item( [ 'billingcycle' => (string) $product_duration ], $cart_index );
				}
				foreach ( $product_options as $cart_index => $product_option ) {
					$response['pd_response'][] = whcom_add_update_cart_item( [ 'configoptions' => $product_option ], $cart_index );
				}
				foreach ( $product_addons as $cart_index => $product_addon ) {
					$response['pd_response'][] = whcom_add_update_cart_item( [ 'addons' => $product_addon ], $cart_index );
				}
				foreach ( $product_fields as $cart_index => $product_field ) {
					$response['pd_response'][] = whcom_add_update_cart_item( [ 'customfields' => $product_field ], $cart_index );
				}
				ob_start();
				include( WCOP_PATH . '/shortcodes/domain_first/style1/06_checkout.php' );
				$response['response_form'] = ob_get_clean();
				$response['current_cart']  = whcom_get_cart();
				$response['message']       = esc_html__( "Loading Client Form", "whcom" );
				$response['status']        = 'OK';
				break;
			}
		case 'delete_cart_item' :
			{
				$cart_index = esc_attr( $_POST['cart_index'] );
				$response   = whcom_delete_cart_item( $cart_index );
				if ( $response['status'] == 'OK' ) {
					ob_start();
					include( WCOP_PATH . '/shortcodes/domain_first/style1/06_checkout.php' );
					$response['response_form'] = ob_get_clean();
				}
				break;
			}
		case 'submit_order' :
			{
				if ( ! empty( $_POST['paymentmethod'] ) ) {
					whcom_add_update_cart_item( [ 'paymentmethod' => (string) $_POST['paymentmethod'] ] );
					$response = whcom_submit_order();
					if ( ! empty( $response['result'] ) && ( $response['result'] == 'success' ) ) {
						if ( wcop_use_merchant_gateway() ) {
							$_POST['invoiceid'] = $response['invoiceid'];
							ob_start();
							include( WCOP_PATH . '/shortcodes/domain_first/style1/07_capture_payment.php' );
							$response['response_form'] = ob_get_clean();
						}
						else {
							$response['response_form'] = $response['invoice_link'];
						}
						$response['message'] = esc_html__( "Invoice Generated", "whcom" );
						$response['status']  = 'OK';
					}
					else {
						$response['status'] = 'OK';
					}
				}
				else {
					$response['message'] = esc_html__( 'No Payment method selected', "whcom" );
					$response['status']  = 'ERROR';
				}
				break;
			}
		case 'capture_payment' :
			{
				$_POST['clientid'] = whcom_get_current_client_id();
				$_POST['expdate']  = esc_attr( $_POST['exp_month'] ) . esc_attr( $_POST['exp_year'] );
				$response          = wcop_capture_payment_function( $_POST );
				ob_start();
				include( WCOP_PATH . '/shortcodes/domain_first/style1/08_launch.php' );
				$response['response_form'] = ob_get_clean();
				break;
			}
		default :
			{
				$response['message'] = esc_html__( "Something went wrong, kindly try again later ...", "whcom" );
				$response['status']  = 'ERROR';
			}
	}
	echo json_encode( $response, JSON_FORCE_OBJECT );
	die();
}

add_action( 'wp_ajax_wcop_domain_first', 'wcop_domain_first' );
add_action( 'wp_ajax_nopriv_wcop_domain_first', 'wcop_domain_first' );














