<?php defined( 'ABSPATH' ) or die( "Cannot access pages directly." );

require_once( WCOP_PATH . '/inc/cart-functions.php' );
require_once( WCOP_PATH . '/inc/ajax-functions.php' );


function wcop_render_domain_config_form( $domain = '', $type = 'register', $cart_index = '-1' ) {
	$response = [
		'status'        => "ERROR",
		'response_form' => "",
		'message'       => esc_html__( 'Something went wrong, kindly try again later ...', "whcom" )
	];
	if ( ! empty( $domain ) ) {
		$redirect_url = get_option( 'cart_listing_page' . whcom_get_current_language() );
		$domain       = whcom_get_domain_clean( $domain );
		$type         = ( $type == 'transfer' ) ? 'transfer' : 'register';
		$tld          = whcom_get_tld_from_domain( $domain );
		$tld_details  = whcom_get_tld_details( $tld );
		$tld_prices   = [];
		$nameservers  = whcom_get_nameservers();
		if ( ! empty( $tld_details[ $type . '_price' ] ) ) {
			foreach ( $tld_details[ $type . '_price' ] as $dur => $price ) {
				if ( $price >= 0 ) {
					$tld_prices[ $dur ] = $price;
				}
			}
		}
		ob_start(); ?>
		<form class="wcop_add_domain_to_cart" method="post">
			<div class="whcom_sub_heading_style_1"><span><?php esc_html_e( 'Domain Configuration', "whcom" ) ?></span>
			</div>
			<input type="hidden" name="action" value="wcop_add_domain_to_cart">
			<input type="hidden" name="domain" value="<?php echo $domain; ?>">
			<input type="hidden" name="domaintype" value="<?php echo $type; ?>">
			<input type="hidden" name="landing_page" value="<?php echo $redirect_url ?>">
			<?php if ( $cart_index > - 1 ) {
				echo '<input type="hidden" name="cart_index" value="' . $cart_index . '">';
			} ?>
			<?php if ( $type == 'register' ) { ?>
				<div class="whcom_form_field whcom_form_field_horizontal">
					<label class="main_label"><?php esc_html_e( 'Domain Duration', "whcom" ) ?></label>
					<select name="regperiod" class="wcop_input" title="Domain Duration">
						<?php foreach ( $tld_prices as $dur => $det ) {
							$dur_txt = esc_html__( 'For', "whcom" );
							$dur_txt .= ' ' . $dur . ' ';
							$dur_txt .= ( $dur == 1 ) ? esc_html__( 'Year', "whcom" ) : esc_html__( 'Years', "whcom" );
							echo '<option value="' . $dur . '">' . whcom_format_amount( $det ) . ' ' . $dur_txt . '</option>';
							if ( $type == 'transfer' ) {
								break;
							}
						}
						?>
					</select>
				</div>
				<?php echo whcom_render_tld_specific_fields( $tld ); ?>
			<?php } ?>
			<?php echo whcom_render_tld_specific_addons( $tld, - 1, $type ); ?>
			<div class="whcom_sub_heading_style_1"><span><?php esc_html_e( 'Domain Nameservers', "whcom" ); ?></span>
			</div>
			<div class="wcop_domain_nameservers">
				<div class="whcom_form_field whcom_form_field_horizontal">
					<label for="inputNs1" class="main_label"><?php esc_html_e( 'Nameserver 1', "whcom" ); ?></label>
					<input type="text"
					       class="form-control"
					       id="inputNs1"
					       name="domainns1"
					       value="<?php echo $nameservers['ns1']; ?>">
				</div>
				<div class="whcom_form_field whcom_form_field_horizontal">
					<label for="inputNs2" class="main_label"><?php esc_html_e( 'Nameserver 2', "whcom" ); ?></label>
					<input type="text"
					       class="form-control"
					       id="inputNs2"
					       name="domainns2"
					       value="<?php echo $nameservers['ns2']; ?>">
				</div>
				<div class="whcom_form_field whcom_form_field_horizontal">
					<label for="inputNs3" class="main_label"><?php esc_html_e( 'Nameserver 3', "whcom" ); ?></label>
					<input type="text"
					       class="form-control"
					       id="inputNs3"
					       name="domainns3"
					       value="<?php echo $nameservers['ns3']; ?>">
				</div>
				<div class="whcom_form_field whcom_form_field_horizontal">
					<label for="inputNs4" class="main_label"><?php esc_html_e( 'Nameserver 4', "whcom" ); ?></label>
					<input type="text"
					       class="form-control"
					       id="inputNs4"
					       name="domainns4"
					       value="<?php echo $nameservers['ns4']; ?>">
				</div>
				<div class="whcom_form_field whcom_form_field_horizontal">
					<label for="inputNs5" class="main_label"><?php esc_html_e( 'Nameserver 5', "whcom" ); ?></label>
					<input type="text"
					       class="form-control"
					       id="inputNs5"
					       name="domainns5"
					       value="<?php echo $nameservers['ns5']; ?>">
				</div>
			</div>
			<?php if ( $type == 'transfer' ) { ?>
				<div class="whcom_sub_heading_style_1">
					<span><?php esc_html_e( 'Authorization Code', "whcom" ); ?></span>
				</div>
				<div class="whcom_form_field whcom_form_field_horizontal">
					<label for="inputAuthCode"><?php esc_html_e( 'Authorization Code', "whcom" ); ?></label>
					<input type="text"
					       class="form-control"
					       name="epp"
					       id="inputAuthCode"
					       placeholder="Epp Code / Auth Code"
					       required="required">
				</div>
			<?php } ?>
			<div class="wcop_domain_config_response_text"></div>
			<div class="whcom_form_field whcom_text_center">
				<button type="submit"><?php esc_html_e( 'Add to Cart', "whcom" ) ?></button>
			</div>
		</form>

		<?php
		$response['response_form'] = ob_get_clean();
	}

	return $response;
}

function wcop_render_product_domain_config_fields( $domain = '', $type = 'register', $cart_index = '-1' ) {
	if ( empty( $domain ) ) {
		return false;
	}

	$domain      = whcom_get_domain_clean( $domain );
	$type        = ( $type == 'transfer' ) ? 'transfer' : 'register';
	$tld         = whcom_get_tld_from_domain( $domain );
	$tld_details = whcom_get_tld_details( $tld );
	$tld_prices  = [];
	if ( ! empty( $tld_details[ $type . '_price' ] ) ) {
		foreach ( $tld_details[ $type . '_price' ] as $dur => $price ) {
			if ( $price >= 0 ) {
				$tld_prices[ $dur ] = $price;
			}
		}
	}

	$cart_item       = whcom_get_cart_item( $cart_index );
	$domain_duration = ( ! empty( $cart_item ) && ! empty( $cart_item['regperiod'] ) ) ? '' : $cart_item['regperiod'];

	ob_start(); ?>
	<div class="wcop_product_domain">
		<input type="hidden" name="domain" value="<?php echo $domain; ?>">
		<input type="hidden" name="domaintype" value="<?php echo $type; ?>">
		<?php if ( $cart_index > - 1 ) {
			echo '<input type="hidden" name="cart_index" value="' . $cart_index . '">';
		} ?>
		<div class="whcom_form_field whcom_form_field_horizontal">
			<label class="main_label"><?php esc_html_e( 'Domain Duration', "whcom" ) ?></label>
			<select name="regperiod" class="wcop_input" title="Domain Duration">
				<?php
				$c = 0;
				foreach ( $tld_prices as $dur => $det ) {
					$selected = ( ( $c == 0 ) && empty( $domain_duration ) ) ? 'selected' : '';
					if ( $dur == $domain_duration ) {
						$selected = 'selected';
					}
					$dur_txt = esc_html__( 'for', 'whcom' );
					$dur_txt .= ' ' . $dur . ' ';
					$dur_txt .= ( $dur == 1 ) ? esc_html__( 'Year', "whcom" ) : esc_html__( 'Years', "whcom" );
					echo '<option value="' . $dur . '" ' . $selected . '>' . whcom_format_amount( $det ) . ' ' . $dur_txt . '</option>';
					if ( $type == 'transfer' ) {
						break;
					}
					$c ++;
				}
				?>
			</select>
		</div>
		<?php echo whcom_render_tld_specific_addons( $tld, $cart_index, $type ) ?>
		<?php if ( $type == 'register' ) {
			echo whcom_render_tld_specific_fields( $tld, $cart_index );
		} ?>
	</div>

	<?php
	return ob_get_clean();
}

function wcop_get_current_domain_details( $domain = '', $type = 'register', $regperiod = '1', $product, $billingcycle ) {
	$response               = [
		'is_free' => false
	];
	$billingcycle           = (string) $billingcycle;
	$domain                 = whcom_get_domain_clean( $domain );
	$tld                    = whcom_get_tld_from_domain( $domain );
	$tld_details            = whcom_get_tld_details( $tld );
	$regperiod              = esc_attr( $regperiod );
	$product                = ( ! empty( $product ) && is_array( $product ) ) ? $product : whcom_get_product_details( (int) $product );
	$freedomain             = ( (string) $product['freedomain'] == 'on' || (string) $product['freedomain'] == 'once') ? true : false;
	$freedomaintlds         = explode( ',', (string) $product['freedomaintlds'] );
	$freedomainpaymentterms = explode( ',', (string) $product['freedomainpaymentterms'] );
	if ( ( $freedomain ) && in_array( $tld, $freedomaintlds ) && in_array( $billingcycle, $freedomainpaymentterms ) ) {
		$response['is_free'] = true;
	}
	foreach ( $tld_details[ $type . '_price' ] as $dur => $prc ) {
		$response['domain_duration'] = ' ' . $dur . ' ';
		$response['domain_duration'] .= ( (int) $dur == 1 ) ? esc_html__( 'Year', "whcom" ) : esc_html__( 'Years', "whcom" );;
		$response['domain_price'] = $prc;
		$response['domain_type']  = ( $type == 'register' ) ? esc_html__( 'Registration For', "whcom" ) : esc_html__( 'Transfer For', "whcom" );
		if ( $response['is_free'] ) {
			$response['domain_free']  = 'yes';
			$response['regperiod']    = $dur;
			$response['domain_price'] = 0.00;
			break;
		}
		if ( $dur == $regperiod ) {
			break;
		}
	}

	return $response;
}

function wcop_use_merchant_gateway() {
	$response = false;
	if ( get_option( 'use_merchant_gateway', '' ) == 'yes' ) {
		$response = true;
	}

	return $response;
}



